==> 0.6.1.tar.gz: lief/include/LIEF/ELF/DynamicEntryLibrary.hpp <==
/* Copyright 2017 R. Thomas
 * Copyright 2017 Quarkslab
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef LIEF_ELF_DYNAMIC_ENTRY_LIBRARY_H_
#define LIEF_ELF_DYNAMIC_ENTRY_LIBRARY_H_

#include <string>

#include "LIEF/visibility.h"

#include "LIEF/ELF/DynamicEntry.hpp"

namespace LIEF {
namespace ELF {
class DLL_PUBLIC DynamicEntryLibrary : public DynamicEntry {

  public:
    DynamicEntryLibrary(const Elf64_Dyn* header);
    DynamicEntryLibrary(const Elf32_Dyn* header);
    DynamicEntryLibrary(void);

    DynamicEntryLibrary(const std::string& name = "");

    DynamicEntryLibrary& operator=(const DynamicEntryLibrary& copy);
    DynamicEntryLibrary(const DynamicEntryLibrary& copy);

    virtual const std::string& name(void) const override;
    virtual void name(const std::string& name) override;

    virtual void accept(Visitor& visitor) const override;

    virtual std::ostream& print(std::ostream& os) const override;

  private:
    std::string libname_;
};
}
}

#endif

==> 0.8.2.tar.gz: lief/include/LIEF/ELF/DynamicEntryLibrary.hpp <==
/* Copyright 2017 R. Thomas
 * Copyright 2017 Quarkslab
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef LIEF_ELF_DYNAMIC_ENTRY_LIBRARY_H_
#define LIEF_ELF_DYNAMIC_ENTRY_LIBRARY_H_

#include <string>

#include "LIEF/visibility.h"

#include "LIEF/ELF/DynamicEntry.hpp"

namespace LIEF {
namespace ELF {
class DLL_PUBLIC DynamicEntryLibrary : public DynamicEntry {

  public:
    using DynamicEntry::DynamicEntry;

    DynamicEntryLibrary(const Elf64_Dyn* header);
    DynamicEntryLibrary(const Elf32_Dyn* header);
    DynamicEntryLibrary(void);
    DynamicEntryLibrary(const std::string& name = "");

    DynamicEntryLibrary& operator=(const DynamicEntryLibrary&);
    DynamicEntryLibrary(const DynamicEntryLibrary&);

    virtual const std::string& name(void) const override;
    virtual void name(const std::string& name) override;

    virtual void accept(Visitor& visitor) const override;

    virtual std::ostream& print(std::ostream& os) const override;

  private:
    std::string libname_;
};
}
}

#endif
